/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer PpoxyRenewal: PpoxyRenewal BaseAction Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: ProxyRenewalAction.h,v 1.2 2006/08/10 12:04:27 badino Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_TRANSFER_PROXYRENEWAL_PROXYRENEWALACTION_H_
#define GLITE_DATA_TRANSFER_PROXYRENEWAL_PROXYRENEWALACTION_H_

#include "glite/data/transfer/agent/action/Action.h"
#include "glite/data/transfer/agent/action/ExecuteException.h"
#include "glite/data/agents/dao/DAOContext.h"
#include "glite/data/transfer/agent/dao/cred/CredDAO.h"
#include "glite/data/transfer/agent/dao/cred/JobDAO.h"
#include "glite/data/agents/AgentExceptions.h"

#include <string>
#include <boost/scoped_ptr.hpp>
#include <set>

namespace log4cpp{
    class Category;
}

namespace glite       {
namespace data        {
namespace transfer    {
namespace proxyrenewal{
        
/**
 * Base Class For all the ProxyRenewal Actions
 */
class ProxyRenewalAction : public agent::action::Action {
public:    
    
    /**    
     * set DAOContext
     */
    virtual void context(const std::string& name, glite::data::agents::dao::DAOContext& ctx);
    
    /**    
     * Get DAOContext
     */
    virtual glite::data::agents::dao::DAOContext& context() /*throw (LogicError)*/;
    
    /**    
     * Get Agent Name
     */
    virtual const std::string& agentName() const {
        return m_agentName;
    }
    
    /**
     * Destructor
     */
    virtual ~ProxyRenewalAction();

    /**
     * Execute The Action
     */
    virtual void execute(const std::string& params = "") /*throw (LogicError,ExecuteException)*/;

protected:

    /**
     * Constructor
     */
    ProxyRenewalAction(const std::string& name);

    /**
     * Call the virtual method to execute the action (Template Pattern)
     */
    virtual void exec(const std::string& params) /*throw (LogicError, DAOException, ExecuteException)*/ = 0;

protected:

    typedef glite::data::transfer::agent::dao::cred::CredDAO  CredDAO;
    typedef glite::data::transfer::agent::dao::cred::JobDAO   JobDAO;

    /**    
     * Get a CredDAO Instance
     */
    CredDAO& credDAO() /*throw (LogicError)*/;

    /**    
     * Get a JobDAO Instance
     */
    JobDAO& jobDAO() /*throw (LogicError)*/;
        
    /**
     * The Logger
     */
    mutable class log4cpp::Category& m_logger;

private:
    
    /**
     * The DAO Context
     */
    glite::data::agents::dao::DAOContext* m_context;

    /**
     * The DAO Context
     */
    std::string m_agentName;
    
    /**
     * The Channel DAO
     */
    boost::scoped_ptr<CredDAO> m_credDAO;
    
    /**
     * The Channel DAO
     */
    boost::scoped_ptr<JobDAO> m_jobDAO;
};

} // End namespace proxyrenewal
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_PROXYRENEWAL_PROXYRENEWALACTION_H_
