/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer Proxyrenewal: Heartbeat Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: Heartbeat.cpp,v 1.1.1.1 2006/08/02 08:01:40 badino Exp $
 *  Release: $Name:  $
 *
 */
#include "Heartbeat.h"
#include "glite/data/transfer/agent/AgentHeartbeat.h"

#include "glite/data/transfer/agent/dao/cred/DAOFactory.h"

#include "log4cpp/Category.hh"
#include <set>

using namespace glite::data::transfer::proxyrenewal;
using namespace glite::data::transfer::agent;
using namespace log4cpp;

using glite::data::agents::dao::DAOException;
using glite::data::transfer::agent::action::ExecuteException;

/*
 * Register ActionFactory Method 
 */
REGISTER_FACTORY_METHOD( Heartbeat );
      
/*
 * Heartbeat
 *
 * Constructor
 */
Heartbeat::Heartbeat():ProxyRenewalAction("ProxyRenewalHeartbeat"){
}

/*
 * ~Heartbeat
 *
 * Destructor
 */
Heartbeat::~Heartbeat(){
}

/*
 * execute
 *
 * Execute the Action
 */
void Heartbeat::execute(const std::string& params) /*throw (ExecuteException, LogicError)*/{
    
    try{
        // Create Agent Heartbeat
        AgentHeartbeat<dao::cred::DAOFactory> hb;
        // Run Heartbeat
        hb.run(this->context(),this->agentName());
    } catch(const DAOException& exc){
        throw ExecuteException(exc.what());
    }
}
