/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer ProxyRenewal: ProxyRenewalAgent Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: ProxyRenewalAgent.h,v 1.1.1.1 2006/08/02 08:01:40 badino Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_TRANSFER_PROXYRENEWAL_PROXYRENEWAL_AGENT_H_
#define GLITE_DATA_TRANSFER_PROXYRENEWAL_PROXYRENEWAL_AGENT_H_

#include "glite/data/config/service/ComponentConfiguration.hxx"
#include "glite/data/transfer/agent/scheduler/ActionScheduler.h"
#include <string>
#include <vector>
#include <boost/scoped_ptr.hpp>

namespace log4cpp{
    class Category;
}

namespace glite   {
namespace data    {
namespace transfer{
	
/*
 * Forward Declaration
 */    
namespace agent{
namespace action{
class ActionFactoryMethod;
}
}
namespace proxyrenewal{
    

/**
 * The ProxyRenewalAgent Class
 */    
class ProxyRenewalAgent : public glite::config::ComponentConfiguration ,
                		  public glite::data::transfer::agent::ActionScheduler::Listener{
public:
    /**
     * Initialize the Component
     */
    virtual int init(const Params& params);
                                                                                                                           
    /**
     * Configure the Component
     */
    virtual int config(const Params& params);
                                                                                                                           
    /**
     * Start the Component
     */
    virtual int start();
                                                                                                                           
    /**
     * Stop the Component
     */
    virtual int stop();
                                                                                                                           
    /**
     * Finailize the Component
     */
    virtual int fini();
    
    // ActionScheduler Listener Methods
    
    /**
     * Handle Event Start. This method would be called on the Scheduler
     * Thread when the thread is started
     */
    virtual bool onEventStart() /*throw()*/;
    /**
     * Handle Event Stop. This method would be called when the Scheduler
     * Thread when the thread is going to stop
     */
    virtual bool onEventStop() /*throw()*/;
    
protected:
    
    friend ComponentConfiguration * ::create_glite_component();
    friend void ::destroy_glite_component(ComponentConfiguration * component);

    /**
     * Constructor
     */
    ProxyRenewalAgent();
                                                                                                                           
    /**
     * Destructor
     */
    virtual ~ProxyRenewalAgent();
                        
private:

    /**
     * Initialize the Scheduler
     */
    void initScheduler() /*throw(ConfigException)*/;

    /**
     * Add a schedulerEntry for the given Action Type
     */
    void scheduleAction(const std::string& type, unsigned int interval, const std::string& params = "") /*throw(ConfigException)*/;

    /**
     * Add a schedulerEntry for the given Action Factory Method
     */
    void scheduleAction(class glite::data::transfer::agent::action::ActionFactoryMethod& method, unsigned int interval, const std::string& params = "") /*throw(ConfigException)*/;

    /**
     * Finalize the Scheduler
     */
    void finiScheduler();

private:
    
   /**
     * The Logger
     */
    class log4cpp::Category& m_logger;
                        
    /**
     * Agent Contact
     */
    std::string m_contact;
    /**
     * Renew Action Type
     */
    std::string m_renewType;
    /**
     * Default Action Interval
     */
    unsigned int m_defaultInterval;
    /**
     * Renew Action Interval
     */
    unsigned int m_renewInterval;
    /**
     * Heartbeat Action Interval
     */
    unsigned int m_heartbeatInterval;
    /**
     * CleanSDCache Action Interval
     */
    unsigned int m_cleansdcacheInterval;
    /**
     * Action Scheduler
     */
    boost::scoped_ptr<class glite::data::transfer::agent::ActionScheduler> m_scheduler;
        
    /**
     * The DAO Context
     */
    boost::scoped_ptr<class glite::data::agents::dao::DAOContext> m_daoCtx;
};

} // end namespace proxyrenewal
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif //GLITE_DATA_TRANSFER_PROXYRENEWAL_PROXYRENEWAL_AGENT_H_
