/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer ProxyRenewal: ProxyRenewalConfig Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: ProxyRenewalConfig.h,v 1.2 2006/08/02 14:22:00 badino Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_TRANSFER_PROXYRENEWAL_PROXYRENEWAL_PROXYRENEWALCONFIG_H_
#define GLITE_DATA_TRANSFER_PROXYRENEWAL_PROXYRENEWAL_PROXYRENEWALCONFIG_H_

#include "glite/data/config/service/ComponentConfiguration.hxx"
#include <string>
#include <boost/utility.hpp>

namespace log4cpp{
    class Category;
}

namespace glite   {
namespace data    {
    
/*
 * Forward Declaration
 */
namespace agents   {
namespace dao   {
class DAOContext;
}
}
    
namespace transfer    {
namespace proxyrenewal{

/**
 * ProxyRenewalConfig class (used to retrieve the Configuration 
 * Parameters from the ServiceConfigurator)
 */    
class ProxyRenewalConfig :  boost::noncopyable, public glite::config::ComponentConfiguration {
public:

	static ProxyRenewalConfig& instance();

    /**
     * Configure the Component
     */
    virtual int init(const Params& params);
    
    /**
     * Configure the Component
     */
    virtual int config(const Params& params);
                                                                                                                           
    /**
     * Start the Component
     */
    virtual int start(){return 0;}
                                                                                                                           
    /**
     * Stop the Component
     */
    virtual int stop(){return 0;}
                                                                                                                           
    /**
     * Finailize the Component
     */
    virtual int fini();

    // =========================================================================
    // Configuration Properties
    // =========================================================================
                     
    /**
     * MyProxy Server Host
     */
    const std::string& myproxyServer() const { return m_myproxyServer;}
                                                                                                                                                          
    /**
     * MyProxy Server Port
     */
    unsigned int myproxyPort() const { return m_myproxyPort;}
                                                                                                                                                          
    /**
     * Proxy Certificate Lifetime
     */
    unsigned long proxyLifetime() const {return m_proxyLifetime;}
                                                                                                                                                          
    /**
     * Minimum Valibity Time for a Proxy Certificate
     */
    unsigned long minValidityTime() const { return m_minValidityTime; }

    // =========================================================================
    // Helper Function
    // =========================================================================
    
protected:
    /**
     * Constructor
     */
    ProxyRenewalConfig();
                                                                                                                           
    /**
     * Destructor
     */
    virtual ~ProxyRenewalConfig();
        
private:
    
    /**
     * The Logger
     */
    mutable class log4cpp::Category& m_logger;
        
    /**
     * MyProxy Server Host
     */
    std::string m_myproxyServer;
                                                                                                                                                          
    /**
     * MyProxy Server Port
     */
    unsigned int m_myproxyPort;
                                                                                                                                                          
    /**
     * Proxy Certificate Lifetime
     */
    unsigned long m_proxyLifetime;
                                                                                                                                                          
    /**
     * Minimum Valibity Time for a Proxy Certificate
     */
    unsigned long m_minValidityTime;
};

} // end namespace proxyrenewal
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif //GLITE_DATA_TRANSFER_PROXYRENEWAL_PROXYRENEWAL_PROXYRENEWALCONFIG_H_
