/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer ProxyRenewal: Renew Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: Renew.h,v 1.2 2006/08/10 15:34:46 badino Exp $
 *  Release: $Name:  $
 *
 */
#ifndef GLITE_DATA_TRANSFER_PROXYRENEWAL_PROXYRENEWAL_RENEW_H_
#define GLITE_DATA_TRANSFER_PROXYRENEWAL_PROXYRENEWAL_RENEW_H_

#include "glite/data/transfer/proxyrenewal/ProxyRenewalAction.h"
#include "glite/data/transfer/agent/action/ActionFactoryMethod.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace proxyrenewal{

/**
 * The purpose of that Action is to cancel Renew certificates
 */
class Renew : public ProxyRenewalAction {
    /*
     * Declare Action Factory Method
     */
    DECLARE_FACTORY_METHOD( Renew , "glite:Renew");

public:
    /**
     * Constructor
     */
    Renew();

    /**
     * Destructor
     */
    virtual ~Renew();

protected:

    /**
     * Execute The Action
     */
    virtual void exec(const std::string& params) /*throw (DAOException, ExecuteException, LogicError)*/;

private:

    /**
     * Renew teh credentials
	 */
	void renewCred(class glite::data::transfer::agent::model::Cred& c) /*throw (ExecuteException, LogicError)*/;

	/**
	 * Write a certificate into a file
	 */
	void writeCertificate(const std::string& cert, int fd) /*throw (ExecuteException, LogicError)*/;

	/**
	 * Read a certificate from a file
	 */
	void readCertificate(const std::string& cert_file, std::string& new_cert) /*throw (ExecuteException, LogicError)*/;

	/**
	 * Get the Myproxy server to be used to renew the given credentials
	 */
	void getMyProxyServer(const glite::data::transfer::agent::model::Cred& c, const std::string& proxy_file, std::string& myproxy_server, unsigned int& myproxy_port) /*throw ()*/;
};


} // End namespace proxyrenewal
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_PROXYRENEWAL_PROXYRENEWAL_RENEW_H_
