/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer ProxyRenewal: main function
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: TestProxyRenewal.cpp,v 1.2 2006/08/23 14:02:11 badino Exp $
 *  Release: $Name:  $
 *
 */
#include "DaoHelper.h"
#include "glite/data/config/service/glite-config.h"
#include "glite/data/config/service/glite-config-register.hxx"

#include <cstdlib>
#include <cstring>
#include <iostream>
#include <unistd.h>
#include <cppunit/extensions/TestFactoryRegistry.h>
#include <cppunit/ui/text/TestRunner.h>
#include <cppunit/CompilerOutputter.h>

using std::cout;
using std::cerr;
using std::cin;
using std::endl;

namespace {
const char * const CONFIG_NAME = "glite-transfer-proxyrenewal-test-proxyrenewal";
const char * const PROGNAME    = "glite_data_transfer_proxyrenewal_test_proxyrenewal";
const char * const PROGVERSION = "0.0";
const char * const PROGAUTHOR  = "(C) EGEE";
}

char * g_user_dn = 0;
/*
 * print_usage_and_die
 *
 * Print Program Usage and ther exit
 */
void print_usage_and_die(){
    cout << endl;
    cout << "<" << PROGNAME << "> Version " << PROGVERSION << " by " << PROGAUTHOR;
    cout << endl;
    cout << "usage: " << PROGNAME << " -d <user_dn> [-l <glite_location_user>] [-s]" << endl;
    cout << " Where:" << endl;
    cout << " -l : specify the glite location. Configuration files should be located under the etc folder on that path" << endl;
    cout << " -s : Enable the Compiler Outputter" << endl;
    cout << " -d : User DN" << endl;
    cout << " -c : configuration" << endl;
    cout << " Where:" << endl;
    cout << " Optional parameters:" << endl;
    cout << "  -h : print this screen" << endl;
    exit(-1);
}

/*
 * suite
 *
 * Instantiate Test Suite
 */
CppUnit::Test * suite() {

    CppUnit::TestFactoryRegistry& registry = CppUnit::TestFactoryRegistry::getRegistry();
    CppUnit::TestFactoryRegistry& proxyrenewalTestCase = CppUnit::TestFactoryRegistry::getRegistry("RenewTestCase");
    registry.registerFactory(&proxyrenewalTestCase);
    return registry.makeTest();
}


/*
 * main
 *
 * Transfer FTS Main function
 */
int main(int argc, char* argv[]) {

    // Get Options
    const char * location = 0;
    const char * config   = CONFIG_NAME;
    bool selfTest = false;
    int flag;
    while ((flag = getopt (argc, argv, "c:l:d:sh")) != -1) {
        switch (flag) {
            case 'c':
                config = optarg;
            break;
            case 'l':
                location = optarg;
            break;
            case 'd':
                g_user_dn = optarg;
            break;
            case 's':
                selfTest = true;
            break;
            case 'h':
            default:
                print_usage_and_die();
            break;
        } // End switch
    } // End while

	if((0 == g_user_dn) || (0 == strlen(g_user_dn))){
		print_usage_and_die();
	}

    if(0 != location){
        // Set "GLite Location User"
        setenv("GLITE_LOCATION",location,1);
    }
    
    // Initialize the Application
    int initres = glite_config_initialize(config);
    if(initres < 0){
        cerr << "Initialization failed " << endl;
        return -1;
    }
    
    CppUnit::TextUi::TestRunner runner;
    runner.addTest(suite());   // Add the suite to the test runner

    if(true == selfTest){ 
        // Change the default outputter to a compiler error format outputter
        // The test runner owns the new outputter.
        runner.setOutputter( 
           CppUnit::CompilerOutputter::defaultOutputter(&runner.result(),cerr));
    }
          
    // Run the test
    bool wasSucessful = runner.run();

    DaoHelper::dispose();
    
    // Finalize the Application
    glite_config_finalize();
        
    return wasSucessful ? 0 : 1;
}
